@@ -356,7 +356,7 @@ void detaileddialog::setProcessorThrottling() {
 			// get max cpu freq and set it to the max of the progressbar
 			ProcessorPBar[i]->setTotalSteps(100);
 			TQString ProgressString = TQString("%1% (%2 MHz)").arg(100 - cpuInfo->cpu_throttling[i]).arg(cpuInfo->cpufreq_speed[i]);
-			ProcessorPBar[i]->setFormat(i18n(ProgressString.ascii()));
+			ProcessorPBar[i]->setFormat(i18n(ProgressString.utf8()));
 			ProcessorPBar[i]->setProgress(100 - cpuInfo->cpu_throttling[i]);
 			ProcessorPBar[i]->setEnabled(true);
 		} else if (cpuInfo->cpufreq_speed[i] < 0) {
@@ -411,7 +411,7 @@ void detaileddialog::setInfos() {
 
 	if(!config->currentScheme.isEmpty())
 		display += i18n("Current Scheme: ") + "\n";
-		displayValue += i18n(config->currentScheme.ascii()) + "\n";
+		displayValue += i18n(config->currentScheme.utf8()) + "\n";
 		if(config->currentScheme == config->ac_scheme)
 			InfoPictogram->setPixmap(SmallIcon("scheme_power", 22));
 		else if(config->currentScheme == config->battery_scheme)
