@@ -219,9 +219,6 @@ private:
 	//! a menu seperator ID
 	/*! contains the ID of the separator between autosuspend and Help*/
 	int HELP_SEPARATOR_MENU_ID;
-	//! a menu ID
-	/*! contains the ID of the help menu*/
-	int HELP_MENU;
 
 	//! number of white pixel in the kickerapplet icon
 	/*!
@@ -269,9 +266,6 @@ private:
 	//! a sub-menu of the kickerapplet
 	/*! TQPopupMenu for the scheme-entries. */
 	TQPopupMenu *scheme_menu;
-	//! a sub-menu of the kickerapplet
-	/*! TQPopupMenu for the help-entries. */
-	TQPopupMenu *help_menu;
 
 
 	//! icon-pixmap
@@ -356,8 +350,6 @@ private slots:
 	void slotHelp();
 	//! called to open the kpowersave About dialog
 	void slotAbout();
-	//! called to open website to report bugs
-	void slotReportBug();
 	//! called if the configure dialog is destroyed
 	void observeConfigDlg();
 	//! called if user exit from kpowersave
